
API
===

.. module:: django_auth_iam.models

Models
------

.. autoclass:: User
   :members:

.. autoclass:: Group
   :members:

Utilities
---------

.. module:: django_auth_iam.utils

.. autofunction:: encrypt_key

.. autofunction:: decrypt_key
